netapp_ontap.models.storage_switch_errors API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_switch_errors`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageSwitchErrorsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageSwitchErrors object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `component: StorageSwitchErrorsComponent GET POST PATCH`

    The component field of the storage_switch_errors.

  `reason: Error GET`

    The reason field of the storage_switch_errors.

  `severity: str GET POST PATCH`

    Error component severity

    Valid choices:

    - unknown
    - notice
    - warning
    - error
  `type: str GET POST PATCH`

    Error component type

    Valid choices:

    - switch_unreachable
    - temp_above_warning_level
    - temp_above_critical_level
    - temp_below_warning_level
    - temp_below_critical_level
    - temp_sensor_status_failed
    - fan_status_non_operational
    - power_supply_status_failed
    - power_above_warning_level
    - power_above_critical_level
    - power_below_warning_level
    - power_below_critical_level
    - sfp_rx_power_above_warning_level
    - sfp_rx_power_above_critical_level
    - sfp_tx_power_above_warning_level
    - sfp_tx_power_above_critical_level
    - sfp_rx_power_below_warning_level
    - sfp_rx_power_below_critical_level
    - sfp_tx_power_below_warning_level
    - sfp_tx_power_below_critical_level
    - sfp_status_failed
    - vsan_invalid_frame_delivery_configuration
    - temp_sensor_status_unavailable
    - fan_status_unavailable
    - power_supply_inline_power_failed
    - power_supply_status_unavailable
    - unknown
    - power_supply_off_env_other
    - power_supply_off_admin
    - power_supply_off_denied
    - power_supply_off_env_power
    - power_supply_off_env_temp
    - power_supply_off_env_fan
    - power_supply_on_but_fan_fail
    - power_supply_off_cooling
    - power_supply_off_connector_rating
    - e_ports_down
    - snmpv3_user_not_configured
    - incomplete_snmp_data_refresh